import { Container } from '@mui/material';
import { Route, Routes } from 'react-router-dom';
import { AppToolbar } from './components/UI/AppToolbar';
import { Products } from './containers/Products';
import { NewProductForm } from './containers/NewProductForm';
import { Auth } from './containers/Auth';
import { ProtectedRoute } from './components/ProtectedRoute';
import { useAppDispatch, useAppSelector } from './store/hook';
import { useEffect } from 'react';
import { validateToken } from './features/usersSlice';

function App() {
  const dispatch = useAppDispatch()
  const {user} = useAppSelector(state => state.users)

  useEffect(() => {
    dispatch(validateToken())
  }, [dispatch])

  return (
    <>
      <header>
        <AppToolbar user={user}/>
      </header>
      <main>
        <Container maxWidth="xl" sx={{ mt: 10 }}>
          <Routes>
            <Route path="/" element={
              <ProtectedRoute user={user}>
                <Products />
              </ProtectedRoute>
            }/>
            <Route path="/products/new" element={
              <ProtectedRoute user={user}>
                <NewProductForm />
              </ProtectedRoute>
            }/>
            <Route path='/auth' element={<Auth/>} />
          </Routes>
        </Container>
      </main>
    </>
  );
}

export default App;
