import { IUserState, logout } from '@/features/usersSlice';
import { useAppDispatch } from '@/store/hook';
import { AppBar, Box, Button, Toolbar, Typography, styled } from '@mui/material';
import { Link } from 'react-router-dom';

const StyledLink = styled(Link)(() => ({
  color: 'inherit',
  textDecoration: 'none',
  ['&:hover']: { color: 'inherit' }
}));

const StyledBox = styled(Link)(() => ({
  width: '200px',
  display: 'flex',
  justifyContent: 'space-between',
  textDecoration: 'none',
  color: 'white'
}));

export function AppToolbar({user}: {user: IUserState | null}) {
  const dispatch = useAppDispatch()

  return (
    <>
      <AppBar position="fixed">
        <Toolbar style={{display: 'flex', justifyContent: 'space-between'}}>
          <Typography variant="h6" component={StyledLink} to={'/'}>
            Computer parts shop
          </Typography>
          {
            user &&
            <Box component={StyledBox}>
              <Typography variant="h6" component={StyledLink} to={'/'}>
                  {user?.username}
              </Typography>
              <Button variant="contained" onClick={() => dispatch(logout(user?.id))}>
                Logout
              </Button>
            </Box>
          }
        </Toolbar>
      </AppBar>
    </>
  );
}
