import { Register } from "@/components/Register";
import { SignIn } from "@/components/SignIn";
import { IUserError } from "@/features/usersSlice";
import { useAppSelector } from "@/store/hook";
import { notification, Row, Tabs, TabsProps } from "antd";
import { useEffect } from "react";
import { useNavigate } from "react-router-dom";

const items: TabsProps['items'] = [
    {
      key: '1',
      label: 'Sign In',
      children: <SignIn/>,
    },
    {
      key: '2',
      label: 'Registration',
      children: <Register/>,
    },
]

export const Auth = () => {
    const navigate = useNavigate()
    const {user, error} = useAppSelector(state => state.users)

    useEffect(() => {
      if(user) navigate('/')
    }, [navigate, user])

    useEffect(() => {
      if(error) {
        (error as IUserError[]).map(item => (
          notification.error({
            message: item.type,
            description: item.messages[0],
            duration: 2
          })
        ))
      }
    }, [error])

    return (
       <Row 
            align={'middle'}
            justify={'center'}
            style={{height: '90vh'}}
        >
             <Tabs 
                defaultActiveKey="1" 
                items={items}
            />
       </Row>
    )
}