import { createAsyncThunk, createSlice } from "@reduxjs/toolkit";
import { axiosApiClient } from "../helpers/axiosApiClient";
import { ICategory } from "@/components/UI/Form/CategorySelect";
import { IProduct } from "@/containers/Products";

export interface IProductState {
  id: string;
  title: string;
  description: string;
  price: number;
  image: string;
  category: ICategory
}

interface State {
  products: IProductState[];
  error: Error | null;
  loading: boolean;
}

const initialState: State = {
  products: [],
  error: null,
  loading: false
};

export const fetchProducts = createAsyncThunk('fetch/products', async () => {
  const token = localStorage.getItem('token')
  return await axiosApiClient.get<IProductState[]>('/products', {headers: {Authorization: token}}).then(res => res.data);
});

export const createProduct = createAsyncThunk('create/product', 
  async (payload: Omit<FormData, "id">) => {
    const token = localStorage.getItem('token')
    return axiosApiClient.post<IProduct>("/products/create", payload, {headers: {Authorization: token}})
      .then(res => res.data);
});

const productsSlice = createSlice(
  {
    name: 'products',
    initialState,
    reducers: {},
    extraReducers(builder) {
      builder.addCase(fetchProducts.fulfilled, (state, action) => {
        state.products = action.payload;
        state.loading = false;
      }).addCase(fetchProducts.rejected, (state, action) => {
        state.loading = false;
        state.error = action.error as Error;
      })
      .addCase(fetchProducts.pending, (state) => {
        state.loading = true;
      })
    },
  }
)

export default productsSlice.reducer;
