import { ProductService } from '@/services/product.service';
import { RequestHandler } from 'express';
import { plainToInstance } from 'class-transformer';
import { ProductDto } from '@/dto/product.dto';
import { formatErrors } from '@/helpers/formatErrors';

export class ProductController {
  private service: ProductService;

  constructor() {
    this.service = new ProductService();
  }

  getAllProducts: RequestHandler = async (req, res): Promise<void> => {
    const products = await this.service.getAllProducts();
    res.send(products);
  };

  getProduct: RequestHandler = async (req, res): Promise<void> => {
    const product = await this.service.getProduct(req.params.id);
    res.send(product);
  };

  createProduct: RequestHandler = async (req, res): Promise<void> => {
    try {
      const productDto = plainToInstance(ProductDto, req.body);
      if (req.file) productDto.image = req.file.filename;
      const product = await this.service.createProduct(productDto);
      res.send(product);
    } catch (e) {
      if (Array.isArray(e)) {
        res.status(400).send(formatErrors(e));
      } else {
        res.status(500).send(e);
      }
    }
  };
}
