import { Entity, PrimaryGeneratedColumn, Column, Unique } from "typeorm";
import bcrypt from 'bcrypt';
import { UserRoles } from "@/interfaces/IUser.interface";

const SALT_WORK_FACTOR = 10;
@Entity()
@Unique(['username'])
export class User {
    @PrimaryGeneratedColumn()
    id!: number;

    @Column()
    username!: string

    @Column()
    password!: string

    @Column({nullable: true})
    token!: string

    @Column({nullable: true})
    displayName!: string

    @Column({default: UserRoles.user})
    role!: string

    async comparePassword(password: string): Promise<boolean> {
        return await bcrypt.compare(password, this.password);  
    }

    async hashPassword() {
        const salt = await bcrypt.genSalt(SALT_WORK_FACTOR)
        this.password = await bcrypt.hash(this.password, salt)
    }

    generateToken() {
        this.token = crypto.randomUUID();
    }
}