import { AppDataSource } from "@/appDataSource";
import { ProductDto } from "@/dto/product.dto";
import { Product } from "@/entities/product.entity";
import { Repository } from "typeorm";
import { categoryRepo } from "./category.repository";

class ProductRepo {
    private repo: Repository<Product>

    constructor() {
        this.repo = AppDataSource.getRepository(Product)
    }

    async create(body: ProductDto) {
        const category = await categoryRepo.getOne(parseInt(body.categoryId))
        if(!category) throw Error('Category Not Found.')
        
        return await this.repo.save({...body, category: category})
    }

    async getAll() {
        return await this.repo.find({relations: {category: true}})
    }

    async getOne(id: number) {
        return await this.repo.findOne({where: {id: id}})
    }
}

export const productRepo = new ProductRepo()