import { Router } from 'express';
import { ArticleController } from '../controllers/article.controller';
import { IRoute } from '../interfaces/IRoute.interface';
import { authValidate } from '@/middlewares/auth.middleware';
import { checkRole } from '@/middlewares/checkRole';

export class ArticleRoute implements IRoute {
  public path = '/articles';
  public router = Router();
  private controller: ArticleController;

  constructor() {
    this.controller = new ArticleController();
    this.init();
  }

  private init() {
    this.router.get('/', authValidate, this.controller.getAllArticles);
    this.router.get('/:id', authValidate, this.controller.getArticle);
    this.router.post('/create', authValidate, checkRole('admin'), this.controller.createArticle);
  }
}
