import { ProductController } from '@/controllers/product.controller';
import { authValidate } from '@/middlewares/auth.middleware';
import { checkRole } from '@/middlewares/checkRole';
import upload from '@/middlewares/storage';
import { Router } from 'express';

export class ProductRoute {
  public path = '/products';
  public router = Router();
  private controller: ProductController;

  constructor() {
    this.controller = new ProductController();
    this.init();
  }

  private init() {
    this.router.get('/', authValidate, this.controller.getAllProducts);
    this.router.get('/:id', authValidate, this.controller.getProduct);
    this.router.post('/create', authValidate, checkRole('admin'), upload.single('image') ,this.controller.createProduct);
  }
}
