import { SignInUserDto } from "@/dto/sign-in-user.dto"
import { RegistrationUserDto } from "@/dto/registration-user.dto"
import { userRepo } from "@/repositories/user.repository"
import { validate } from "class-validator"

export class UserService {
    async signIn(signInUserDto: SignInUserDto) {
        const errors = await validate(signInUserDto, { whitelist: true })
        if (errors.length) throw errors
        return await userRepo.signIn(signInUserDto)
    }

    async registration(registrationUserDto: RegistrationUserDto) {
        const errors = await validate(registrationUserDto, { whitelist: true })
        if (errors.length) throw errors
        return await userRepo.registration(registrationUserDto)
    }

    async validateToken(token?: string) {
        return await userRepo.validateToken(token)
    }

    async logout(userId: number) {
        return await userRepo.logout(userId)
    }
}
